## PDFMathTranslate

PDF 科学论文翻译和双语对照。 - 📊 保留公式、图表、目录和注释 _([预览](#preview))_。 - 🌐 支持[多种语言](https://pdf2zh-next.com/supported_languages.html)和多样的[翻译服务](https://pdf2zh-next.com/advanced/Documentation-of-Translation-Services.html)。 - 🤖 提供[命令行工具](https://pdf2zh-next.com/getting-started/USAGE_commandline.html)、[交互式用户界面](https://pdf2zh-next.com/getting-started/USAGE_webui.html)和[Docker](https://pdf2zh-next.com/getting-started/INSTALLATION_docker.html) 欢迎在[GitHub Issues](https://github.com/PDFMathTranslate/PDFMathTranslate-next/issues)或[Telegram 群组](https://t.me/+Z9_SgnxmsmA5NzBl)中提供反馈。 有关如何贡献的详细信息，请查阅[贡献指南](https://pdf2zh-next.com/community/Contribution-Guide.html)。

## 更新

- [2025 年 6 月 4 日] 项目重命名并迁移至 [PDFMathTranslate/PDFMathTranslate-next](https://github.com/PDFMathTranslate/PDFMathTranslate-next) (由 [@awwaawwa](https://github.com/awwaawwa) 提供) - [2025 年 3 月 3 日] 新后端 [BabelDOC](https://github.com/funstory-ai/BabelDOC) WebUI 作为实验选项添加 (由 [@awwaawwa](https://github.com/awwaawwa) 提供) - [2025 年 2 月 22 日] 更好的发布 CI 和打包良好的 windows-amd64 exe (由 [@awwaawwa](https://github.com/awwaawwa) 提供) - [2024 年 12 月 24 日] 译者现在支持 [Xinference](https://github.com/xorbitsai/inference) 上的本地模型 _(由 [@imClumsyPanda](https://github.com/imClumsyPanda) 提供)_ - [2024 年 12 月 19 日] 现在支持非 PDF/A 文档使用 `-cp` _(由 [@reycn](https://github.com/reycn) 提供)_ - [2024 年 12 月 13 日] 额外支持后端 _(由 [@YadominJinta](https://github.com/YadominJinta) 提供)_ - [2024 年 12 月 10 日] 译者现在支持 Azure 上的 OpenAI 模型 _(由 [@yidasanqian](https://github.com/yidasanqian) 提供)_

## 预览

## 在线服务 🌟

> [!NOTE] > > pdf2zh 2.0 目前不提供在线演示 您可以通过以下任一演示来试用我们的应用程序： - [v1.x 公共免费服务](https://pdf2zh.com/) 在线使用，无需安装 _(推荐)_。 - [沉浸式翻译 - BabelDOC](https://app.immersivetranslate.com/babel-doc/) 每月 1000 页免费。_(推荐)_ 请注意，演示的计算资源有限，请避免滥用。

## 安装和使用

### 安装 1. [**Windows EXE**](https://pdf2zh-next.com/getting-started/INSTALLATION_winexe.html) 推荐用于 Windows 2. [**Docker**](https://pdf2zh-next.com/getting-started/INSTALLATION_docker.html) 推荐用于 Linux 3. [**uv** (一个 Python 包管理器)](https://pdf2zh-next.com/getting-started/INSTALLATION_uv.html) 推荐用于 macOS --- ### 使用 1. [使用 **WebUI**](https://pdf2zh-next.com/getting-started/USAGE_webui.html) 2. [使用 **Zotero 插件**](https://github.com/guaguastandup/zotero-pdf2zh) (第三方程序) 3. [使用 **命令行**](https://pdf2zh-next.com/getting-started/USAGE_commandline.html) 对于不同的使用场景，我们提供不同的方法来使用我们的程序。请查看[此页面](./getting-started/getting-started.md)以获取更多信息。

## 高级选项

有关详细说明，请参阅我们的[高级用法](https://pdf2zh-next.com/advanced/advanced.html)文档以获取每个选项的完整列表。

## 二次开发 (API)

> [!NOTE] > > 目前没有提供相关文档。将会在后续补充。请耐心等待。

## 语言代码

如果您不知道要使用什么代码来翻译成所需的语言，请查看[此文档](https://pdf2zh-next.com/advanced/Language-Codes.html)

## 致谢

    - [沉浸式翻译](https://immersivetranslate.com) 为本项目的活跃贡献者提供每月 Pro 会员兑换码，详情请参阅：[CONTRIBUTOR_REWARD.md](https://github.com/funstory-ai/BabelDOC/blob/main/docs/CONTRIBUTOR_REWARD.md)

    - 1.x 版本：[Byaidu/PDFMathTranslate](https://github.com/Byaidu/PDFMathTranslate)

    - 新后端：[BabelDOC](https://github.com/funstory-ai/BabelDOC)

    - 文档合并：[PyMuPDF](https://github.com/pymupdf/PyMuPDF)

    - 文档解析：[Pdfminer.six](https://github.com/pdfminer/pdfminer.six)

    - 文档提取：[MinerU](https://github.com/opendatalab/MinerU)

    - 文档预览：[Gradio PDF](https://github.com/freddyaboulton/gradio-pdf)

    - 多线程翻译：[MathTranslate](https://github.com/SUSYUSTC/MathTranslate)

    - 布局解析：[DocLayout-YOLO](https://github.com/opendatalab/DocLayout-YOLO)

    - 文档标准：[PDF Explained](https://zxyle.github.io/PDF-Explained/), [PDF Cheat Sheets](https://pdfa.org/resource/pdf-cheat-sheets/)

    - 多语言字体：[Go Noto Universal](https://github.com/satbyy/go-noto-universal)

    - [异步化](https://github.com/multimeric/Asynchronize/tree/master?tab=readme-ov-file)

    - [多进程日志记录](https://github.com/SebastianGrans/Rich-multiprocess-logging/tree/main)

## 提交代码前

我们欢迎贡献者积极参与使 pdf2zh 更加完善。在您准备提交代码之前，请参阅我们的[行为准则](https://pdf2zh-next.com/community/CODE_OF_CONDUCT.html)和[贡献指南](https://pdf2zh-next.com/community/Contribution-Guide.html)。

## 贡献者

![Alt](https://repobeats.axiom.co/api/embed/45529651750579e099960950f757449a410477ad.svg "Repobeats analytics image")

## Star 历史